FormBuilderTextField class

A Material Design text field input.

Inheritance

Constructors

FormBuilderTextField({Key? key, required String name, FormFieldValidator<String>? validator, InputDecoration decoration = const InputDecoration(), ValueChanged<String?>? onChanged, ValueTransformer<String?>? valueTransformer, bool enabled = true, FormFieldSetter<String>? onSaved, AutovalidateMode? autovalidateMode = AutovalidateMode.disabled, VoidCallback? onReset, FocusNode? focusNode, String? restorationId, String? forceErrorText, String? initialValue, FormFieldErrorBuilder? errorBuilder, bool readOnly = false, int? maxLines = 1, bool obscureText = false, TextCapitalization textCapitalization = TextCapitalization.none, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), bool enableInteractiveSelection = true, MaxLengthEnforcement? maxLengthEnforcement, TextAlign textAlign = TextAlign.start, bool autofocus = false, bool autocorrect = true, double cursorWidth = 2.0, double? cursorHeight, TextInputType? keyboardType, TextStyle? style, TextEditingController? controller, TextInputAction? textInputAction, StrutStyle? strutStyle, TextDirection? textDirection, int? maxLength, VoidCallback? onEditingComplete, ValueChanged<String?>? onSubmitted, List<TextInputFormatter>? inputFormatters, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, InputCounterWidgetBuilder? buildCounter, bool expands = false, int? minLines, bool? showCursor, GestureTapCallback? onTap, TapRegionCallback? onTapOutside, bool enableSuggestions = true, TextAlignVertical? textAlignVertical, DragStartBehavior dragStartBehavior = DragStartBehavior.start, ScrollController? scrollController, ScrollPhysics? scrollPhysics, BoxWidthStyle selectionWidthStyle = ui.BoxWidthStyle.tight, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, BoxHeightStyle selectionHeightStyle = ui.BoxHeightStyle.tight, Iterable<String>? autofillHints, String obscuringCharacter = '•', MouseCursor? mouseCursor, EditableTextContextMenuBuilder? contextMenuBuilder = _defaultContextMenuBuilder, TextMagnifierConfiguration? magnifierConfiguration, ContentInsertionConfiguration? contentInsertionConfiguration, SpellCheckConfiguration? spellCheckConfiguration, Clip clipBehavior = Clip.hardEdge, @Deprecated('This property will be removed in the next Flutter stable versions. ' 'Use FocusNode.canRequestFocus instead. ' 'Ref: https://docs.flutter.dev/release/breaking-changes/can-request-focus') bool canRequestFocus = true, Color? cursorErrorColor, bool? cursorOpacityAnimates, bool enableIMEPersonalizedLearning = true, Object groupId = EditableText, AppPrivateCommandCallback? onAppPrivateCommand, bool onTapAlwaysCalled = false, @Deprecated('Use `stylusHandwritingEnabled` instead. ' 'This feature was deprecated after v3.27.0-0.2.pre.') bool scribbleEnabled = true, bool stylusHandwritingEnabled = EditableText.defaultStylusHandwritingEnabled, TextSelectionControls? selectionControls, WidgetStatesController? statesController, UndoHistoryController? undoController})
Creates a Material Design text field input.

Properties

autocorrect → bool
Whether to enable autocorrection.
final
autofillHints → Iterable<String>?
A list of strings that helps the autofill service identify the type of this text input.
final
autofocus → bool
Whether this text field should focus itself if nothing else is already focused.
final
autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
buildCounter → InputCounterWidgetBuilder?
Callback that generates a custom InputDecorator.counter widget.
final
builder → FormFieldBuilder<String>
Function that returns the widget representing this form field.
finalinherited
canRequestFocus → bool
Determine whether this text field can request the primary focus.
final
clipBehavior → Clip
The content will be clipped (or not) according to this option.
final
contentInsertionConfiguration → ContentInsertionConfiguration?
Configuration of handler for media content inserted via the system input method.
final
contextMenuBuilder → EditableTextContextMenuBuilder?
Builds the text selection toolbar when requested by the user.
final
controller → TextEditingController?
Controls the text being edited.
final
cursorColor → Color?
The color to use when painting the cursor.
final
cursorErrorColor → Color?
The color of the cursor when the InputDecorator is showing an error.
final
cursorHeight → double?
How tall the cursor will be.
final
cursorOpacityAnimates → bool?
Whether the cursor will animate from fully transparent to fully opaque during each cursor blink.
final
cursorRadius → Radius?
How rounded the corners of the cursor should be.
final
cursorWidth → double
How thick the cursor will be.
final
decoration → InputDecoration
finalinherited
dragStartBehavior → DragStartBehavior
Determines the way that drag start behavior is handled.
final
enabled → bool
Whether the form is able to receive user input.
finalinherited
enableIMEPersonalizedLearning → bool
Whether to enable that the IME update personalized data such as typing history and user dictionary data.
final
enableInteractiveSelection → bool
Whether to enable user interface affordances for changing the text selection.
final
enableSuggestions → bool
final
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
expands → bool
Whether this widget's height will be sized to fill its parent.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
groupId → Object
The group identifier for the TextFieldTapRegion of this text field.
final
hashCode → int
The hash code for this object.
no setterinherited
initialValue → String?
An optional value to initialize the form field to, or null otherwise.
finalinherited
inputFormatters → List<TextInputFormatter>?
Optional input validation and formatting overrides.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance → Brightness?
The appearance of the keyboard.
final
keyboardType → TextInputType?
The type of keyboard to use for editing the text.
final
magnifierConfiguration → TextMagnifierConfiguration?
This magnifying glass is useful for scenarios on mobile devices where the user's finger may be covering part of the screen where a granular action is being performed, such as navigating a small cursor with a drag gesture, on an image or text.
final
maxLength → int?
The maximum number of characters (Unicode grapheme clusters) to allow in the text field.
final
maxLengthEnforcement → MaxLengthEnforcement?
final
maxLines → int?
The maximum number of lines to show at one time, wrapping if necessary.
final
minLines → int?
The minimum number of lines to occupy when the content spans fewer lines.
final
mouseCursor → MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
final
name → String
Used to reference the field within the form, or to reference form data after the form is submitted.
finalinherited
obscureText → bool
Whether to hide the text being edited (e.g., for passwords).
final
obscuringCharacter → String
Character used for obscuring text if obscureText is true.
final
onAppPrivateCommand → AppPrivateCommandCallback?
This is used to receive a private command from the input method.
final
onChanged → ValueChanged<String?>?
Called when the field value is changed.
finalinherited
onEditingComplete → VoidCallback?
Called when the user submits editable content (e.g., user presses the "done" button on the keyboard).
final
onReset → VoidCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → ValueChanged<String?>?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
onSubmitted → ValueChanged<String?>?
Called when the user indicates that they are done editing the text in the field.
final
onTap → VoidCallback?
Called for the first tap in a series of taps.
final
onTapAlwaysCalled → bool
Whether onTap should be called for every tap.
final
onTapOutside → TapRegionCallback?
A callback to be invoked when a tap is detected outside of this TapRegion and any other region with the same groupId, if any.
final
readOnly → bool
By default false
final
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scribbleEnabled → bool
Whether iOS 14 Scribble features are enabled for this widget.
final
scrollController → ScrollController?
The ScrollController to use when vertically scrolling the input.
final
scrollPadding → EdgeInsets
Configures the padding for the edges surrounding a Scrollable when the text field scrolls into view.
final
scrollPhysics → ScrollPhysics?
The ScrollPhysics to use when vertically scrolling the input.
final
selectionControls → TextSelectionControls?
Optional delegate for building the text selection handles.
final
selectionEnabled → bool
no setter
selectionHeightStyle → BoxHeightStyle
Controls how tall the selection highlight boxes are computed to be.
final
selectionWidthStyle → BoxWidthStyle
Controls how wide the selection highlight boxes are computed to be.
final
showCursor → bool?
Whether to show cursor.
final
smartDashesType → SmartDashesType?
final
smartQuotesType → SmartQuotesType?
final
spellCheckConfiguration → SpellCheckConfiguration?
Configuration that details how spell check should be performed.
final
statesController → WidgetStatesController?
Represents the interactive "state" of this widget in terms of a set of WidgetStates, including WidgetState.disabled, WidgetState.hovered, WidgetState.error, and WidgetState.focused.
final
strutStyle → StrutStyle?
The strut style used for the vertical layout.
final
style → TextStyle?
The style to use for the text being edited.
final
stylusHandwritingEnabled → bool
Whether this input supports stylus handwriting, where the user can write directly on top of a field.
final
textAlign → TextAlign
How the text should be aligned horizontally.
final
textAlignVertical → TextAlignVertical?
final
textCapitalization → TextCapitalization
Configures how the platform keyboard will select an uppercase or lowercase keyboard.
final
textDirection → TextDirection?
The directionality of the text.
final
textInputAction → TextInputAction?
The type of action button to use for the keyboard.
final
undoController → UndoHistoryController?
Controls the undo state.
final
validator → FormFieldValidator<String>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited
valueTransformer → ValueTransformer<String?>?
Called just before field value is saved. Used to massage data just before committing the value.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FormBuilderFieldDecorationState<FormBuilderTextField, String>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

noMaxLength → const int
If maxLength is set to this value, only the "current input length" part of the character counter is shown.